@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class TestDjangoAppConfig(AppConfig):
-    name = 'test_django_app'
+    name = "test_django_app"
